require 'spec_helper'
require 'ostruct'

describe Rubotium::TestsRunner do
  let(:device1) { double('Device1') }
  let(:device2) { double('Device2') }
  let(:devices) { [device1, device2] }
  let(:tests) { (0..10).to_a.map{|elem| Rubotium::RunnableTest.new("package#{elem}", "name#{elem}")} }
  let(:test_runner) { double(Rubotium::TestRunners::InstrumentationTestRunner) }
  let(:test_package) { double(Rubotium::Package) }
  let(:successful_test) {OpenStruct.new(:failed? => false )}

  before do
    device1.stub(:name).and_return('device1')
    device2.stub(:name).and_return('device2')
    test_package.stub(:test_runner).and_return('com.android.TestRunner')
    test_package.stub(:name).and_return('com.android.test#testToRun')
  end
  context 'without extra options' do
    let(:runner) { described_class.new(devices, tests, test_package) }

    context 'when running tests' do
      before do
        runner.stub(:memory_results_file).and_return Tempfile.new('memory_monitor')
        device1.stub(:shell)
        device2.stub(:shell)
        runner.stub(:test_runner).and_return(test_runner)
        test_runner.stub(:run_test).with(any_args).and_return(successful_test)
      end

      it 'runs all the tests from the queue' do
        runner.run_tests
        expect(runner.send :tests_queue).to be_empty
      end

      it 'knows how many tests it has' do
        runner.tests_count.should eql(11)
      end
    end
  end
end
